summaryrefslogtreecommitdiff
path: root/ssl/quic/quic_channel_local.h
diff options
context:
space:
mode:
Diffstat (limited to 'ssl/quic/quic_channel_local.h')
-rw-r--r--ssl/quic/quic_channel_local.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/ssl/quic/quic_channel_local.h b/ssl/quic/quic_channel_local.h
index 379528b516..0eb47f3f13 100644
--- a/ssl/quic/quic_channel_local.h
+++ b/ssl/quic/quic_channel_local.h
@@ -122,8 +122,10 @@ struct quic_channel_st {
*/
QUIC_CONN_ID retry_scid;
/* Server only: The DCID we currently use to talk to the peer. */
QUIC_CONN_ID cur_remote_dcid;
+ uint64_t cur_remote_seq_num;
+ uint64_t cur_retire_prior_to;
/* Server only: The DCID we currently expect the peer to use to talk to us. */
QUIC_CONN_ID cur_local_dcid;
@@ -122,8 +122,10 @@ struct quic_channel_st {
*/
QUIC_CONN_ID retry_scid;
- /* Server only: The DCID we currently use to talk to the peer. */
+ /* The DCID we currently use to talk to the peer and its sequence num. */
QUIC_CONN_ID cur_remote_dcid;